==> mongodb-6.0.22.gh.tar.gz: mongo-r6.0.22/src/mongo/watchdog/watchdog_mock.h <==
/**
 *    Copyright (C) 2024-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once
#include "mongo/platform/atomic_word.h"
#include "mongo/watchdog/watchdog.h"

namespace mongo {

/**
 * A mock WatchdogMonitor for use in C++ unit tests.
 *
 */
class WatchdogMonitorMock final : public WatchdogMonitorInterface {
public:
    WatchdogMonitorMock() = default;
    ~WatchdogMonitorMock() = default;

    void pauseChecks();

    void unpauseChecks();

    void start();

    void setPeriod(Milliseconds duration);

    void shutdown();

    std::int64_t getCheckGeneration();

    std::int64_t getMonitorGeneration();

    bool getShouldRunChecks_forTest();

private:
    AtomicWord<bool> _shouldRunChecks{true};
};

}  // namespace mongo

==> mongodb-8.0.12.gh.tar.gz: mongo-r8.0.12/src/mongo/watchdog/watchdog_mock.h <==
/**
 *    Copyright (C) 2024-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once
#include "mongo/platform/atomic_word.h"
#include "mongo/watchdog/watchdog.h"

namespace mongo {

/**
 * A mock WatchdogMonitor for use in C++ unit tests.
 *
 */
class WatchdogMonitorMock final : public WatchdogMonitorInterface {
public:
    WatchdogMonitorMock() = default;
    ~WatchdogMonitorMock() override = default;

    void pauseChecks() override;

    void unpauseChecks() override;

    void start() override;

    void setPeriod(Milliseconds duration) override;

    void shutdown() override;

    std::int64_t getCheckGeneration() override;

    std::int64_t getMonitorGeneration() override;

    bool getShouldRunChecks_forTest() override;

private:
    AtomicWord<bool> _shouldRunChecks{true};
};

}  // namespace mongo
